@@ -11,7 +11,7 @@ except ImportError:
     # NOTE - could use subprocess to get from git?
     __rev__ = "local"
 
-__version__ = "0.11.5"
+__version__ = "0.11.10"
 
 _TEST_ENV = bool(os.environ.get("DP_TEST_ENV", ""))
 _IN_PYTEST = "pytest" in sys.modules
@@ -33,6 +33,7 @@ from .client.api import (
     Embed,
     Group,
     File,
+    FontChoice,
     Formula,
     HTML,
     Text,
@@ -41,7 +42,9 @@ from .client.api import (
     Params,
     Plot,
     Report,
+    ReportFormatting,
     ReportType,
+    ReportWidth,
     Result,
     Run,
     Schedule,
@@ -50,8 +53,9 @@ from .client.api import (
     SelectType,
     Table,
     Text,
+    TextAlignment,
+    TextReport,
     Variable,
-    Visibility,
     by_datapane,
     login,
     logout,
