@@ -1,6 +1,6 @@
 """# API docs for Datapane Client
 
-These docs describe the Python API for building Datapane documents, along with additional information on the Datapane Cloud API.
+These docs describe the Python API for building Datapane documents, along with additional information on the Datapane Teams API.
 
 Usage docs for Datapane can be found at https://docs.datapane.com
 
@@ -8,7 +8,7 @@ These objects are all available under the `datapane` module, via `import datapan
 
 ### Datapane Reports API
 
-The core document APIs are available for both Datapane Community and Datapane Cloud, these are found in `datapane.client.api.report`, including,
+The core document APIs are available for both Datapane Community and Datapane Teams, these are found in `datapane.client.api.report`, including,
 
   - `datapane.client.api.report.core.Report`
   - Layout Blocks
@@ -26,14 +26,14 @@ The core document APIs are available for both Datapane Community and Datapane Cl
     - `datapane.client.api.report.blocks.Code`
     - `datapane.client.api.report.blocks.HTML`
 
-### Datapane Cloud
+### Datapane Teams
 
-Additional API docs are found in `datapane.client.api.cloud` that provide building, deployment, and sharing of data analytics apps and workflows
+Additional API docs are found in `datapane.client.api.teams` that provide building, deployment, and sharing of data analytics apps and workflows
 
-  - `datapane.client.api.cloud.Blob`
-  - `datapane.client.api.cloud.Variable`
-  - `datapane.client.api.cloud.Script`
-  - `datapane.client.api.cloud.Schedule`
+  - `datapane.client.api.teams.Blob`
+  - `datapane.client.api.teams.Variable`
+  - `datapane.client.api.teams.Script`
+  - `datapane.client.api.teams.Schedule`
 
 
 .. note::  These docs describe the latest version of the datapane API available on [pypi](https://pypi.org/project/datapane/)
@@ -49,7 +49,6 @@ import warnings
 
 from .common import HTTPError, Resource
 from .dp_object import DPObjectRef
-from .cloud import Blob, Run, Schedule, Script, Variable
 from .report.blocks import (
     BigNumber,
     Code,
@@ -66,8 +65,9 @@ from .report.blocks import (
     Text,
     Table,
 )
-from .report.core import Report, ReportType, Visibility
+from .report.core import FontChoice, Report, ReportFormatting, ReportType, ReportWidth, TextAlignment, TextReport
 from .runtime import Params, Result, by_datapane, _reset_runtime, _report
+from .teams import Blob, Run, Schedule, Script, Variable
 from .user import login, logout, ping
 from ..utils import IncompatibleVersionError
 from ..config import init
