@@ -6,19 +6,19 @@ from typing import Iterator, Tuple
 
 import click
 
-from datapane.common import JDict
+from datapane.common import DPError, JDict
 
 
-def add_help_text(x: str) -> str:
-    return f"{x}\nPlease run with `dp.enable_logging()`, restart your Jupyter kernel/Python instance, and/or visit https://www.github.com/datapane/datapane to raise issue / discuss if error repeats"
-
-
-class DPError(Exception):
-    def __str__(self):
-        # update the error message with help text
-        return add_help_text(super().__str__())
+def is_jupyter() -> bool:
+    """Checks if inside ipython shell inside browser"""
+    try:
+        return get_ipython().__class__.__name__ == "ZMQInteractiveShell"  # noqa: F821
+    except Exception:
+        return False
 
 
+################################################################################
+# Built-in exceptions
 class IncompatibleVersionError(DPError):
     ...
 
@@ -39,6 +39,10 @@ class UnsupportedFeatureError(DPError):
     ...
 
 
+class InvalidReportError(DPError):
+    ...
+
+
 class MissingCloudPackagesError(DPError):
     def __init__(self, *a, **kw):
         # quick hack until we setup a conda meta-package for cloud
