@@ -5,6 +5,7 @@ from .datafiles import ArrowFormat
 from .dp_types import (
     ARROW_EXT,
     ARROW_MIMETYPE,
+    DPError,
     DPMode,
     HTML,
     JSON,
@@ -28,6 +29,7 @@ from .dp_types import (
     set_dp_mode,
 )
 from .utils import (
+    dict_drop_empty,
     guess_type,
     log,
     log_command,
